/*
 * @Author: CoderNight
 * @Date: 2024-07-11 09:59:34
 * @LastEditTime: 2024-08-02 14:29:00
 * @Description: 
 * @FilePath: \AppH5_min\src\config\axios.js
 */
import axios from "axios";
import Config from "./base.js";
import { goBackToApp } from "@/utils/bridge";

import { showToast, showLoadingToast, closeToast } from "vant";
axios.defaults.baseURL = Config;
// axios.defaults.timeout = 3 * 1000; // 3s


let loadingInstance = null;

function startLoading() {
  loadingInstance = showLoadingToast({
    message: "加载中...",
    forbidClick: true,
    duration: 0,
  });
}

function endLoading() {
  if (loadingInstance) {
    closeToast();
  }
}

// 添加請求攔截器
axios.interceptors.request.use(
  function (config) {
    if (config.headers.loading !== false) startLoading()
    config.headers.token = sessionStorage.getItem("token");
    return config;
  },
  function (error) {
    endLoading();
    return Promise.reject(error);
  }
);

axios.interceptors.response.use(
  function (response) {
    endLoading();
    if (response.data === undefined && response.data.code === undefined) {
      return showToast("网络异常，请检查网络");
    }
    if (response.data.msg == "token失效，请重新登录") {
      goBackToApp('login')
      return Promise.reject(response.data);
    }
    if (response.data.code == "401") {
      showToast("登录过期，请重新登录");
      goBackToApp('login')
      return Promise.reject(response.data);
    }
    return response;
  },
  function (error) {
    endLoading();
    showToast("网络异常，请检查网络");

    // 對響應錯誤作點什麼
    return Promise.reject(error);
  }
);

// export default baseUrl;
